/* swlib - Smith-Waterman search library */
/* Copyright (C) 2001  OKUJI K. Yoshinori <o@bioruby.org>
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
   
   You should have received a copy of the GNU Library General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
   MA 02111-1307, USA.  */

#include <sw.h>

#include <string.h>
#include <ctype.h>
#include <stdlib.h>

/* Create a sequence object from a DNA/AA sequence.  */
sw_err_t
sw_seq_init (sw_seq_t *seq, const char *data)
{
  if (! seq)
    return SW_ERR_BADARG;

  if (data)
    {
      int i;
      char *p;
      size_t len;
      
      len = strlen (data);
      seq->data = (char *) malloc (len + 1);

      for (i = 0, p = seq->data; i < len; i++)
	{
	  /* Ignore non-alphabetic characters.  */
	  if (! isalpha (data[i]))
	    continue;

	  /* Always use upper case.  */
	  *p++ = toupper (data[i]);
	}
      *p = 0;

      seq->len = p - seq->data;
    }
  else
    {
      seq->len = 0;
      seq->data = strdup ("");
    }

  if (! seq->data)
    return SW_ERR_NOMEM;

  return SW_ERR_SUCCESS;
}
